summaryrefslogtreecommitdiffstats
path: root/src/node.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/node.h')
-rw-r--r--src/node.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/node.h b/src/node.h
index f3bdfef..1a2005b 100644
--- a/src/node.h
+++ b/src/node.h
@@ -72,7 +72,7 @@ public:
const TQString id() const { return m_id; }
/**
* Returns the id that is internal to the CNItem to which the
* node belongs to. Returns a null TQString if no tqparentitem
*/
const TQString childId() const { return m_childId; }
/**
@@ -118,7 +118,7 @@ public:
* Associates a CNItem with the node - ie the node belongs to the CNItem,
* and hence gets deleted when the CNItem gets deleted.s
*/
- virtual void setParentItem( CNItem *tqparentItem );
+ virtual void setParentItem( CNItem *parentItem );
/**
* Returns true if the node is part of a CNItem
* (i.e. not between multiple connectors)
@@ -128,7 +128,7 @@ public:
* Returns a pointer to the CNItem to which the node belongs,
* or Null if it doesn't.
*/
- CNItem *tqparentItem() const { return p_parentItem; }
+ CNItem *parentItem() const { return p_parentItem; }
/**
* Remove a specific connector
*/
@@ -72,7 +72,7 @@ public:
/**
* Returns the id that is internal to the CNItem to which the
- * node belongs to. Returns a null TQString if no tqparentitem
+ * node belongs to. Returns a null TQString if no parentitem
*/
const TQString childId() const { return m_childId; }